package com.frontleaves.bungeecross.commands;

import com.frontleaves.bungeecross.BungeeCross;
import com.frontleaves.bungeecross.configuration.VariableStorage;
import net.md_5.bungee.api.CommandSender;
import net.md_5.bungee.api.config.ServerInfo;
import net.md_5.bungee.api.connection.ProxiedPlayer;
import net.md_5.bungee.api.plugin.Command;
import org.jetbrains.annotations.NotNull;

/**
 * 传送到服务器
 *
 * @author 筱锋xiao_lfeng
 * @version v1.0-SNAPSHOT
 * @since v1.0-SNAPSHOT
 */
public class SendToServerCommand extends Command {
    private final BungeeCross plugin;
    public SendToServerCommand(String name, BungeeCross bungeeCross) {
        super(name);
        plugin = bungeeCross;
    }

    @Override
    public void execute(CommandSender commandSender, String @NotNull [] strings) {
        switch (strings.length) {
            case 1: {
                // 权限检查
                if (commandSender.hasPermission("bungeecross.server.jump")) {
                    if (commandSender instanceof ProxiedPlayer) {
                        // 获取内容是否与服务器匹配
                        try {
                            ServerInfo serverInfo = plugin.getProxy().getServers().get(strings[0]);
                            // 检查是否在登录区
                            ServerInfo serverName = plugin.getProxy().getPlayer(commandSender.getName()).getServer().getInfo();
                            if (!VariableStorage.getLoginServer().contains(serverName.getName())) {
                                if (serverName != serverInfo) {
                                    plugin.getProxy().getPlayer(commandSender.getName()).connect(serverInfo);
                                    commandSender.sendMessage(VariableStorage.getPrefix() + "跳转到服务器：" + serverInfo.getName());
                                } else {
                                    commandSender.sendMessage(VariableStorage.getPrefix() + "您正处于 " + serverInfo.getName() + " 服务器中");
                                }
                            } else {
                                commandSender.sendMessage(VariableStorage.getPrefix() + "登录服禁止进行服务器跳转");
                            }
                        } catch (NullPointerException ignore) {
                            commandSender.sendMessage(VariableStorage.getPrefix() + "服务器不存在");
                        }
                    } else {
                        commandSender.sendMessage(VariableStorage.getPrefix() + "该指令只允许玩家进行操作");
                    }
                } else {
                    commandSender.sendMessage(VariableStorage.getPrefix() + "您没有权限");
                }
            }
            break;
            // 管理员操作
            case 2: {
                // 获取内容是否与
                if (commandSender.hasPermission("bungeecross.admin")) {
                    ServerInfo serverInfo = plugin.getProxy().getServers().get(strings[0]);
                    if (serverInfo != null) {
                        ProxiedPlayer player = plugin.getProxy().getPlayer(strings[1]);
                        // 玩家是否已链接
                        if (player != null) {
                            if (player.isConnected()) {
                                ServerInfo playerServer = player.getServer().getInfo();
                                if (playerServer != serverInfo) {
                                    player.connect(serverInfo);
                                    commandSender.sendMessage(VariableStorage.getPrefix() + "已将 " + player.getName() + " 用户传送到 " + serverInfo.getName() + " 服务器");
                                } else {
                                    commandSender.sendMessage(VariableStorage.getPrefix() + "玩家 " + player.getName() + " 正处于 " + playerServer.getName() + " 服务器中");
                                }
                            } else {
                                commandSender.sendMessage(VariableStorage.getPrefix() + "玩家 " + player.getName() + " 不在线");
                            }
                        } else {
                            commandSender.sendMessage(VariableStorage.getPrefix() + "玩家 " + strings[1] + " 不在线");
                        }
                    } else {
                        commandSender.sendMessage(VariableStorage.getPrefix() + "服务器不存在");
                    }
                }
            }
            break;
            default: {
                commandSender.sendMessage(VariableStorage.getPrefix() + "参数无效");
            }
        }
    }
}
