package com.frontleaves.bungeecross.configuration;

import com.frontleaves.bungeecross.BungeeCross;
import lombok.RequiredArgsConstructor;
import net.md_5.bungee.config.Configuration;
import net.md_5.bungee.config.ConfigurationProvider;
import net.md_5.bungee.config.YamlConfiguration;
import org.jetbrains.annotations.NotNull;

import java.io.File;
import java.io.IOException;
import java.io.InputStream;
import java.nio.file.Files;

/**
 * 服务器启动执行操作
 *
 * @author 筱锋xiao_lfeng
 */
@RequiredArgsConstructor
public class ServerEnable {
    private final BungeeCross plugin;

    /**
     * 服务器启动内容
     */
    public void serverStart() {
        this.getConfig();
        this.getProxyServer();
        System.out.println(VariableStorage.getPrefix() + "§c配置文件加载完毕");
    }

    /**
     * 获取配置文件，如果没有则自动创建
     */
    private void checkConfigFile() {
        if (!plugin.getDataFolder().exists()) {
            if (plugin.getDataFolder().mkdir()) {
                plugin.getLogger().info("文件夹创建成功");
            } else {
                plugin.getLogger().info("文件夹创建失败");
            }
        }
        File configFile = new File(plugin.getDataFolder(), "config.yml");
        if (!configFile.exists()) {
            saveDefaultConfig(configFile);
            plugin.getLogger().info("配置文件创建成功");
        }
    }

    /**
     * 获取配置文件
     */
    private void getConfig() {
        this.checkConfigFile();
        Configuration config;
        File configFile;
        // 读取文件信息
        try {
            configFile = new File(plugin.getDataFolder(), "config.yml");
            config = ConfigurationProvider.getProvider(YamlConfiguration.class).load(configFile);
        } catch (IOException e) {
            throw new RuntimeException(e);
        }

        // 读取配置文件
        if (config.getString("server_prefix") != null && !config.getString("server_prefix").isEmpty()) {
            VariableStorage.setPrefix(config.getString("server_prefix"));
        } else {
            VariableStorage.setPrefix("§7[§2Bungee§aCross§7] §r");
        }
        // 读取登录服务器
        if (config.getList("server_login").isEmpty()) {
            this.reloadTheDefaultConfig(configFile);
            return;
        } else {
            VariableStorage.setLoginServer(config.getList("server_login"));
        }
        // 读取大厅服务器
        if (config.getList("server_lobby").isEmpty()) {
            this.reloadTheDefaultConfig(configFile);
        } else {
            VariableStorage.setLobbyServer(config.getList("server_login"));
        }
    }

    /**
     * 获取全部服务器
     */
    private void getProxyServer() {
        VariableStorage.setProxyServer(plugin.getProxy().getServers());
    }

    /**
     * 复制默认配置文件到配置项
     *
     * @param configFile File
     */
    private void saveDefaultConfig(@NotNull File configFile) {
        // 将默认配置文件从资源中复制到插件目录
        try (InputStream inputStream = plugin.getResourceAsStream("config.yml")) {
            Files.copy(inputStream, configFile.toPath());
        } catch (IOException e) {
            throw new RuntimeException(e);
        }
    }

    /**
     * 重新载入新的配置文件
     *
     * @param configFile File
     */
    private void reloadTheDefaultConfig(@NotNull File configFile) {
        File newConfigFile = new File(plugin.getDataFolder(), "config.old.yml");
        try {
            Files.copy(configFile.toPath(), newConfigFile.toPath());
            if (configFile.delete()) {
                this.saveDefaultConfig(configFile);
                plugin.getLogger().warning("配置文件错误，已重新生成新的文件");
                plugin.getLogger().info("旧配置文件已生成 config.old.yml");
            }
        } catch (IOException e) {
            throw new RuntimeException(e);
        }
    }
}
